# Help

## Getting help with Mirascope

If you need help getting started with **Mirascope** or with advanced usage, the following sources may be useful.

### :simple-slack: Slack

The [Mirascope Slack](https://join.slack.com/t/mirascope-community/shared_invite/zt-2ilqhvmki-FB6LWluInUCkkjYD3oSjNA) is a great place to ask questions and get help and chat about Mirascope.

### :material-help: Usage Documentation

The [Learn](./learn/index.md) documentation is the most complete guide on how to get started with **Mirascope**.

### :material-api: SDK API Documentation

The [API Reference](./api/core/anthropic/call.md) give reference docs for the **Mirascope** library, auto-generated directly from the code so it's always up-to-date.

### :simple-github: GitHub Issues

The [Mirascope GitHub Issues](https://github.com/Mirascope/mirascope/issues) are a great place to ask questions and give us feedback.

### :material-email: Email

You can also email us at [support@mirascope.io](mailto:support@mirascope.io) or [feedback@mirascope.io](mailto:feedback@mirascope.io).


## How *you* can help Mirascope

### Star Mirascope on GitHub

⭐️ You can "star" Mirascope on [GitHub](https://github.com/mirascope/mirascope) ⭐️

### Connect with the authors

-   Follow us on GitHub
    -   See other related Open Source projects that might help you with machine learning
-   Follow William Bakst on [Twitter/X](https://twitter.com/WilliamBakst)
    -   Tell me how you use mirascope
    -   Hear about new announcements or releases
-   Connect with William Bakst on [LinkedIn](https://www.linkedin.com/in/wbakst/)
    -   Give me any feedback or suggestions about what we're building

### Post about Mirascope

-   Twitter, Reddit, Hackernews, LinkedIn, and others.
-   We love to hear about how Mirascope has helped you and how you are using it.

### Help Others

We are a kind and welcoming community that encourages you to help others with their questions on GitHub Issues or in our Slack Community.

-   Guide for asking questions
    -   First, search through issues and discussions to see if others have faced similar issues
    -   Be as specific as possible, add minimal reproducible example
    -   List out things you have tried, errors, etc
    -   Close the issue if your question has been successfully answered
-   Guide for answering questions
    -   Understand the question, ask clarifying questions
    -   If there is sample code, reproduce the issue with code given by original poster
    -   Give them solution or possibly an alternative that might be better than what original poster is trying to do
    -   Ask original poster to close the issue

### Review Pull Requests

You are encouraged to review any pull requests. Here is a guideline on how to review a pull request:

-   Understand the problem the pull request is trying to solve
-   Ask clarification questions to determine whether the pull request belongs in the package
-   Check the code, run it locally, see if it solves the problem described by the pull request
-   Add a comment with screenshots or accompanying code to verify that you have tested it
-   Check for tests
    -   Request the original poster to add tests if they do not exist
    -   Check that tests fail before the PR and succeed after
-   This will greatly speed up the review process for a PR and will ultimately make Mirascope a better package
